==> cxf-services-xkms-common-3.3.12-sources.jar: org/apache/cxf/xkms/model/xkms/RespondWithEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * &lt;p&gt;Java class for RespondWithEnum.
 * 
 * &lt;p&gt;The following schema fragment specifies the expected content contained within this class.
 * &lt;pre&gt;
 * &amp;lt;simpleType name="RespondWithEnum"&amp;gt;
 *   &amp;lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#KeyName"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#KeyValue"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#X509Cert"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#X509Chain"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#X509CRL"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#RetrievalMethod"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#PGP"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#PGPWeb"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#SPKI"/&amp;gt;
 *     &amp;lt;enumeration value="http://www.w3.org/2002/03/xkms#PrivateKey"/&amp;gt;
 *   &amp;lt;/restriction&amp;gt;
 * &amp;lt;/simpleType&amp;gt;
 * &lt;/pre&gt;
 * 
 */
@XmlType(name = "RespondWithEnum")
@XmlEnum
public enum RespondWithEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#KeyName")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_KEY_NAME("http://www.w3.org/2002/03/xkms#KeyName"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#KeyValue")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_KEY_VALUE("http://www.w3.org/2002/03/xkms#KeyValue"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#X509Cert")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_X_509_CERT("http://www.w3.org/2002/03/xkms#X509Cert"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#X509Chain")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_X_509_CHAIN("http://www.w3.org/2002/03/xkms#X509Chain"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#X509CRL")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_X_509_CRL("http://www.w3.org/2002/03/xkms#X509CRL"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RetrievalMethod")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_RETRIEVAL_METHOD("http://www.w3.org/2002/03/xkms#RetrievalMethod"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#PGP")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PGP("http://www.w3.org/2002/03/xkms#PGP"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#PGPWeb")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PGP_WEB("http://www.w3.org/2002/03/xkms#PGPWeb"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#SPKI")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SPKI("http://www.w3.org/2002/03/xkms#SPKI"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#PrivateKey")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PRIVATE_KEY("http://www.w3.org/2002/03/xkms#PrivateKey");
    private final String value;

    RespondWithEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static RespondWithEnum fromValue(String v) {
        for (RespondWithEnum c: RespondWithEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}

==> cxf-services-xkms-common-3.5.6-sources.jar: org/apache/cxf/xkms/model/xkms/RespondWithEnum.java <==

package org.apache.cxf.xkms.model.xkms;

import javax.xml.bind.annotation.XmlEnum;
import javax.xml.bind.annotation.XmlEnumValue;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for RespondWithEnum.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * <pre>
 * &lt;simpleType name="RespondWithEnum"&gt;
 *   &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyURI"&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#KeyName"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#KeyValue"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#X509Cert"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#X509Chain"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#X509CRL"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#RetrievalMethod"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#PGP"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#PGPWeb"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#SPKI"/&gt;
 *     &lt;enumeration value="http://www.w3.org/2002/03/xkms#PrivateKey"/&gt;
 *   &lt;/restriction&gt;
 * &lt;/simpleType&gt;
 * </pre>
 * 
 */
@XmlType(name = "RespondWithEnum")
@XmlEnum
public enum RespondWithEnum {

    @XmlEnumValue("http://www.w3.org/2002/03/xkms#KeyName")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_KEY_NAME("http://www.w3.org/2002/03/xkms#KeyName"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#KeyValue")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_KEY_VALUE("http://www.w3.org/2002/03/xkms#KeyValue"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#X509Cert")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_X_509_CERT("http://www.w3.org/2002/03/xkms#X509Cert"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#X509Chain")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_X_509_CHAIN("http://www.w3.org/2002/03/xkms#X509Chain"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#X509CRL")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_X_509_CRL("http://www.w3.org/2002/03/xkms#X509CRL"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#RetrievalMethod")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_RETRIEVAL_METHOD("http://www.w3.org/2002/03/xkms#RetrievalMethod"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#PGP")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PGP("http://www.w3.org/2002/03/xkms#PGP"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#PGPWeb")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PGP_WEB("http://www.w3.org/2002/03/xkms#PGPWeb"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#SPKI")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_SPKI("http://www.w3.org/2002/03/xkms#SPKI"),
    @XmlEnumValue("http://www.w3.org/2002/03/xkms#PrivateKey")
    HTTP_WWW_W_3_ORG_2002_03_XKMS_PRIVATE_KEY("http://www.w3.org/2002/03/xkms#PrivateKey");
    private final String value;

    RespondWithEnum(String v) {
        value = v;
    }

    public String value() {
        return value;
    }

    public static RespondWithEnum fromValue(String v) {
        for (RespondWithEnum c: RespondWithEnum.values()) {
            if (c.value.equals(v)) {
                return c;
            }
        }
        throw new IllegalArgumentException(v);
    }

}
